CompiledGroupedQuery

Struct CompiledGroupedQuery 

pub struct CompiledGroupedQuery {
    pub root: CompiledQuery,
    pub expansions: Vec<ExpansionSlot>,
    pub shape_hash: ShapeHash,
    pub hints: ExecutionHints,
}
A compiled grouped query containing a root query and expansion slots.

Fields

root: CompiledQuery

The root flat query.

expansions: Vec<ExpansionSlot>

Expansion slots to evaluate per root result.

shape_hash: ShapeHash

Structural shape hash covering the root query and all expansion slots.

hints: ExecutionHints

Execution hints derived from the grouped query shape.