pub struct ExpansionSlot {
pub slot: String,
pub direction: TraverseDirection,
pub label: String,
pub max_depth: usize,
pub filter: Option<Predicate>,
pub edge_filter: Option<Predicate>,
}Expand description
A named expansion slot that traverses edges per root result.
Fields
slot: StringSlot name used to key the expansion results.
direction: TraverseDirectionDirection to traverse edges.
label: StringEdge kind (label) to follow.
max_depth: usizeMaximum traversal depth.
filter: Option<Predicate>Optional predicate to filter target nodes in this expansion slot.
None is exactly equivalent to pre-Pack-2 behavior.
Some(_) is not yet implemented; see Pack 3.
edge_filter: Option<Predicate>Optional predicate to filter the traversed edges in this expansion slot.
Only EdgePropertyEq and EdgePropertyCompare are valid here.
None preserves pre-Pack-D behavior (no edge filtering).